@@ -1,7 +1,7 @@
 """
 PyLf is a lightweight Python library for simulating Chinese handwriting. It introduces a great deal of randomness in the
 process of Chinese handwriting to simulate the uncertainty of glyphs written by human beings. Currently, PyLf is built
-on the top of Pillow module.
+on the top of Pillow library.
 """
-from ._handwriting import handwrite
-__version__ = '0.5.2'
+from ._handwriting import *
+__version__ = '1.1.3'
